@@ -5,23 +5,14 @@ c     *************************************************************
       subroutine readspecies(filename,nlin,lev,kerr)
       implicit none
       integer nlin,lev, kerr
-      character*80 filename
+      character*250 filename
+      include 'fsizes.inc'
 
 c     *************************************************************
 c     Original arrays for reading
 c     They have to large enough to read all data provided.
 c     In general only a subset of them will be used
 c     *************************************************************
-      integer NLEVMAX,NLINMAX,NCOLMAX,NTEMPMAX
-c     Maximum number of molecular levels
-      parameter(NLEVMAX=50)
-c     Maximum number of molecular line transitions
-      parameter(NLINMAX=200)
-c     Maximum number of molecular collisional transitions
-      parameter(NCOLMAX=1000)
-c     Maximum number of temperatures for which Kud given
-      parameter(NTEMPMAX=14)
-c
       real energy_lev(NLEVMAX), gdeg(NLEVMAX)
       real Aud(NLINMAX), Kud(NCOLMAX,NTEMPMAX), Temp_Kud(NTEMPMAX)
         real Kud_op(NCOLMAX,NTEMPMAX), ortho(NTEMPMAX)
@@ -32,18 +23,16 @@ c
 
 c     Auxiliary variables for reading
       integer i,itemp,lmax,lmin,dummyi,dummyj,dummyk
-      character*80 dummyline,leer,lamdastring
+      character*250 dummyline,leer,lamdastring
       logical overwr,fileinp,numdef,anames,allstop,lamdaformat
       integer precomm,prestruc,ioerror
 
-
 c     ***********************************************************
 c     New arrays as they are used in the code
 c     ***********************************************************
-      include 'fsizes.inc'
       real molmass,energy(nlev),stgew(nlev)
       real fr(ntra),eina(ntra),einb(ntra),gewratio(ntra)
-      real temp(ntempmax),collrates((nlev*(nlev-1))/2,ntempmax)
+      real temp(NTEMPMAX),collrates((nlev*(nlev-1))/2,NTEMPMAX)
       real clight,cst1,cst2,frmin
       integer lfrom(ntra),lto(ntra)
       integer icount,ntemp
@@ -91,7 +80,7 @@ c     Error messages
 24    format(/,' Inconsistency between para- and ortho-H2 rates !')
 c     Input formats
 41    format(A1)
-42    format(A80)
+42    format(A250)
 
 c     ***********************************************************
 c     Start reading
@@ -151,7 +140,7 @@ c       Check for readability
 c     ***********************************************************
 c     Consistency check for the level numbers
 c     It is assumed that levels are numbered starting 1 and
-c     sequentially up to nlevels
+c     sequentially up to nlevels with increasing energy
 c     ***********************************************************
       lmax=0
       lmin=nlevmax
@@ -259,7 +248,7 @@ c         Check for H2
         read (14,*,err=110,end=110) ncttemp
         endif
 c     Check for readability
-      if (ncttemp.gt.ntempmax) then
+      if (ncttemp.gt.NTEMPMAX) then
        write(6,16)
        goto 500
       endif
@@ -403,12 +392,11 @@ c     ***********************************************************
       real function cij(T,J,K)
       implicit none
       real T
-      integer j,k,ntempmax
+      integer j,k
 
       include 'fsizes.inc'
-      parameter (ntempmax=14)
       real molmass, energy(nlev),stgew(nlev),coldown,boltzmann
-      real temp(ntempmax), coll((nlev*(nlev-1))/2,ntempmax)
+      real temp(NTEMPMAX), coll((nlev*(nlev-1))/2,NTEMPMAX)
       logical downwards
       integer jt,ilocat,jup,jlow,icount,ntemp
       character*8 levnam(nlev)
