@@ -11,10 +11,10 @@ c     ***********************************************************
 
       include 'fsizes.inc'
       real r(ns),dco(ns),vt(ns),vs(ns),rc(ns),tb
-      logical aexit,part1
+      logical aexit,part1,tauwrite
       real*8 dd(ns,nlev)
       integer inum,kerr
-      character*80 mol,names
+      character*250 mol,names
       character yn
 
 c     ************************************************************
@@ -32,7 +32,7 @@ c     ************************************************************
 c     Loops of computation
 c     ************************************************************
       call present(1)
-      call predefine(aexit,part1)
+      call predefine(aexit,part1,tauwrite)
       inum=0
 110   kerr=0
       write(6,21)
@@ -50,7 +50,8 @@ c     ************************************************************
        if (kerr.ne.0) goto 250
       endif
         if (part1) goto 260
-200   call line(inum,mol,tb,r,vs,vt,rc,dco,dd,nn,lev,names,kerr)
+200   call line(inum,mol,tb,r,vs,vt,rc,dco,dd,nn,lev,names,
+     %        tauwrite,kerr)
       if (kerr.ne.0) goto 250
       write(6,23)
       read (5,41) yn
@@ -82,7 +83,7 @@ c     ***********************************************************
       real r(ns),t(ns),dh(ns),dco(ns),vt(ns),vs(ns),rc(ns),dny(ns)
       real caps(ns,ntra),srcs(ns,ntra),tb
       real*8 dd(ns,nlev)
-      character*80 mol,name
+      character*250 mol,name
 
       real ulev(ns,ntra),uext(ntra)
       real vmax
@@ -253,7 +254,8 @@ c     ***********************************************************
 c     Subroutine to compute the observed line profiles
 c     Microturbulent approximation 
 c     ***********************************************************
-      subroutine line(inum,mol,tb,r,vs,vt,rc,dco,dd,nn,lev,name,kerr)
+      subroutine line(inum,mol,tb,r,vs,vt,rc,dco,dd,nn,lev,name,
+     %    tauwrite,kerr)
       implicit none
       integer lev,nn,inum
 
@@ -263,16 +265,18 @@ c     ***********************************************************
       real cap(ns),sc(ns)
       real*8 dd(ns,nlev)
       real p(nstretch),pn(nstretch)
-      real iout(nstretch,-nf:nf),iconv(-nf:nf)
+      real iout(nstretch,-nf:nf),tautot(nstretch,-nf:nf)
+      real iconv(-nf:nf)
       integer indr(nstretch)
-      character*80 mol,name
+      character*250 mol,name
       character*20 mesg
+      logical tauwrite
 
       real uext(ntra),dhlp(ns)
-      real vmax,deltap,dp,dpp,factor,tau,nu0
+      real vmax,deltap,dp,dpp,factor,tau0,nu0
       real sigbeam,dny,ubg,tbeam,cfreq,dv,fwhm,dmap,doff,dist
       real spi,pnorm
-      real ibeam(ns,-nf:nf)
+      real ibeam(ns,-nf:nf),taubeam(ns,-nf:nf)
       integer lin,nff,kerr,ilin,hlev,nbeam,nnp
       integer i,j,il1,il2
 
@@ -327,11 +331,11 @@ c     **********************************************************
 c     Set up the frequency scale for all radial grid points
       call initfreq(vs,vt,nn,vmax,dhlp,kerr)
       nff=int(vmax/dny)+1
-       if (nff.gt.nf) then	
+       if (nff.gt.nf) then
        kerr=1
        write(6,12)
        return
-       endif	
+       endif
 c     Initialize cappa and S from the populations, effective values
       call kapsrc(dco,dd,caps,srcs,nn,lin)
       call effkap(caps,rc,nn,lin)
@@ -379,7 +383,7 @@ c     Reduce the caps and srcs fields to the transition considered
         sc(i)=srcs(i,ilin)
       enddo
 c     Calculate real radiative transfer
-      call stpline(r,vs,vt,cap,sc,nn,ubg,p,indr,iout,nnp,nff,dny)
+      call stpline(r,vs,vt,cap,sc,nn,ubg,p,indr,iout,tautot,nnp,nff,dny)
 c     **********************************************************
 c     Beam integration
 c     **********************************************************
@@ -388,10 +392,10 @@ c     Renormalize displacements to have the beam area=1
       do i=1,nnp
         pn(i)=p(i)/pnorm
       enddo
+      factor=tbeam/nu0**2
 c     Loop for the integration over the beams at different 
 c     displacements, reduction, translation into beam
 c     temperature
-      factor=tbeam/nu0**2
       do i=1,nbeam
        deltap=(dpp+(i-1)*dp)/pnorm
        call intbeam(pn,iout,ubg,iconv,nnp,nff,deltap,spi)
@@ -400,15 +404,37 @@ c     temperature
        enddo
       enddo
 c     **********************************************************
-c     For a better cloud control the optical thickness at
-c     cloud centre and line centre is computed in a seperate run
+c     Double effort in case of writing tau files but allows
+c     for complete code reuse
 c     **********************************************************
-      call taucentral(r,vs,vt,cap,nn,tau)
-      write(6,24) tau
+      if (tauwrite) then
+        do i=1,nbeam
+         deltap=(dpp+(i-1)*dp)/pnorm
+         call intbeam(pn,tautot,0.0,iconv,nnp,nff,deltap,spi)
+         do j=-nff,nff
+          taubeam(i,j)=iconv(j)
+         enddo
+        enddo
+      endif
+c     **********************************************************
+c     For a better cloud control the optical thickness at
+c     cloud centre and line centre was computed in a seperate run
+c     This is obsolete with the implememntation of the tau profiles
+c     taucentral is to be removed in future versions
+c     **********************************************************
+c     call taucentral(r,vs,vt,cap,nn,tau0)
+c     write(6,24) tau0
+      tau0=tautot(1,0)
+      write(6,24) tau0
 c     **********************************************************
 c     Write out the results
 c     **********************************************************
-      call writeline(ibeam,nbeam,nff,dmap,doff,dv,tau,nu0,mesg,name)
+      call writeline(ibeam,nbeam,nff,dmap,doff,dv,tau0,nu0,.false.,
+     %   mesg,name)
+      if (tauwrite) then
+        call writeline(taubeam,nbeam,nff,dmap,doff,dv,tau0,nu0,.true.,
+     %   mesg,name)
+      endif
 c     **********************************************************
 c     End of possible loop
 c     **********************************************************
@@ -454,13 +480,13 @@ c     ************************************************************
 11    format(/////////////////////////////)
 12    format(/,' ------------------------------------------------',
      %  '--------------------')
-21    format(//,24X,'SimLine - Version 2.16')
+21    format(//,24X,'SimLine - Version 2.17')
 22    format(/,5X,' Radiative transfer in molecular lines through ',
      %  'turbulent media')
 23    format(/,26X,' Volker Ossenkopf-Okada')
 24    format(20X,' University Observatory Jena /')
 32    format(14X,' Cologne Observatory for Sub-mm Astronomy')
-25    format(//,27X,'November 29, 2025')
+25    format(//,27X,'January 26, 2026')
 27    format(/,' Credits:',/,' --------')
 28    format(' A precursor of this program was written ',
      %  'by E. Kruegel.')
