@@ -11,7 +11,7 @@ c     ***************************************************************
       integer i,j,l,fixed(0:ns),ipshells
       integer precomm,prestruc,ioerror
       logical oldformat,overwr,fileinp,numdef,anames,allstop
-      character*80 lfile,dummyline
+      character*250 lfile,dummyline
       character*50 quant(6)
       character*90 qlin(6)
       character*40 sprm(2)
@@ -46,7 +46,7 @@ c     Repeated parameters within the shells
 28    format(' Outer radius [pc]: ',$)
 c     Input formats
 41    format(A1)
-42    format(A80)
+42    format(A250)
 43    format(' ')
 44    format(I4)
 45    format(1PG12.5)
@@ -198,7 +198,7 @@ c     Continue smoothly
               parm(i+1,j,1)=parm(i,j,1)*(rs(i)/rs(i-1))**parm(i,j,2)
               write(6,45) parm(i+1,j,1)
             else
-c     Read other parameters	
+c     Read other parameters
               read (5,*,err=180) parm(i+1,j,l)
             endif
           enddo
@@ -285,7 +285,7 @@ c     Shell table in new format
         write(14,46) rs(i), (parm(i,j,1),j=1,6)
       enddo
       endif
-      close(14)	
+      close(14)
 c     *************************************************************
 c     Final treatment:
 c     Fill the core with constant parameters to allow a simplified 
@@ -311,6 +311,8 @@ c     New format - compute exponents
       fixed(0)=1
       fixed(1)=1
       fixed(ishell)=1
+c     Do not allow for zero radii as input
+      if (rs(1).eq.0.0) rs(1)=0.1e-3*rs(2)
       do i=ishell,2,-1
 c       Check for too low temperatures
         if (parm(i,2,1).lt.tb) then
@@ -351,7 +353,7 @@ c     *************************************************************
 
 c     *************************************************************
 c     Error handling
-c     *************************************************************	
+c     *************************************************************
 120   goto (100) ioerror(lfile,1)
       kerr=1
       return
@@ -379,7 +381,7 @@ c     ***************************************************************
 
       integer precomm,prestruc,ioerror
       logical overwr,fileinp,numdef,anames,allstop
-      character*80 lfile,dummyline
+      character*250 lfile,dummyline
       character yn
 
       common /accgrid/ epsn,epsv,dvgauss,hyster,minspac,minedge
@@ -416,7 +418,7 @@ c     ***************************************************************
 38    format(' Relative accuracy as convergence criterion: ',$)
 c     Input formats
 41    format(A1)
-42    format(A80)
+42    format(A250)
 43    format(' ')
 44    format(I4)
 45    format(1PG12.5)
@@ -596,7 +598,7 @@ c     The hysteresis factor in the program is 1 for zero hysteresis
       return
 c     *************************************************************
 c     Error handling
-c     *************************************************************	
+c     *************************************************************
 120   goto (100) ioerror(lfile,1)
       inum=0
       return
@@ -619,7 +621,7 @@ c     ***************************************************************
       implicit none
       integer ilin,lin,nmap,iuplev,ilolev
       real fwhm,dist,dmap,doff,dny
-      character*80 lfile,dummyline
+      character*250 lfile,dummyline
       character yn
       integer precomm,prestruc,ioerror,theline
       logical overwr,fileinp,numdef,anames,allstop
@@ -642,7 +644,7 @@ c     Formats for interactive parameter input
 20    format(' Distance of the cloud [pc]: ',$)
 c     Input formats
 41    format(A1)
-42    format(A80)
+42    format(A250)
 43    format(' ')
 44    format(I4)
 45    format(1PG12.5)
@@ -755,7 +757,7 @@ c     *************************************************************
       return
 c     *************************************************************
 c     Error handling
-c     *************************************************************	
+c     *************************************************************
 120   goto (100) ioerror(lfile,1)
       ilin=-1
       return
@@ -856,7 +858,7 @@ c     ***********************************************************
 c     real ulev(ns,ntra)
       integer i,l,ioerror,lend
 
-      character*80 mol,lfile,leer,newname
+      character*250 mol,lfile,leer,newname
 
       integer precomm,prestruc
       logical overwr,fileinp,numdef,anames,allstop
@@ -866,9 +868,9 @@ c     real ulev(ns,ntra)
 
 13    format(' Name of the file for the level populations: ',$)
 c     Input formats
-42    format(A80)
+42    format(A250)
 c     Output lines
-43    format(A80)
+43    format(A250)
 44    format(2i4,1P,E11.4)
 45    format(i4,1P,5E14.6)
 46    format(i4,1P,51E14.7)
@@ -900,7 +902,7 @@ c     *************************************************************
 100   continue
 c     do 200 i=1,nn
 c     write(14,47) i,(ulev(i,l), l=1,lin)
-c 200	continue
+c 200   continue
       close(14)
       return
 
@@ -926,11 +928,11 @@ c     ***********************************************************
       real*8 dd(ns,nlev)
       integer i,l,idum,ioerror
 
-      character*80 mol,lfile
+      character*250 mol,lfile
 
 13    format(' Name of the file giving the level populations: ',$)
 c     Input formats
-42    format(A80)
+42    format(A250)
 
 350   write(6,13)
       read (5,42) lfile
@@ -950,7 +952,7 @@ c     *************************************************************
 
 c     *************************************************************
 c     Error handling
-c     *************************************************************	
+c     *************************************************************
 120   goto (350) ioerror(lfile,1)
       kerr=1
       return
@@ -964,7 +966,7 @@ c     Subroutine to write out the line profiles in a form that
 c     can be read by idl, greg or gnuplot
 c     ***********************************************************
       subroutine writeline(ibeam,nbeam,nff,dtrans,doff,dny,tau,
-     %                                                 nu0,mesg,lfile)
+     %                                            nu0,istau,mesg,lfile)
       implicit none
       integer nbeam,nff
 
@@ -973,21 +975,22 @@ c     ***********************************************************
       real dtrans,doff,dny,tau,nu0
       integer istruc,icomm,i,j,ioerror
       integer precomm,prestruc
-      logical overwr,fileinp,numdef,anames,allstop
+      logical overwr,fileinp,numdef,anames,allstop,istau
 
 c     Variables for FITS file write
       real daten(ns*(2*nf+1))
       real v0(0:3),dv(0:3),convert
-      integer nax(3),kerr,lend,mend
+      integer nax(3),kerr,lend,mend,usedlen
       character*8 units(0:3)
       character*40 comm(0:3)
       character*4 stdext(3),useext
 
-      character*80 lfile,newname,leer
+      character*250 lfile,newname,leer
       character*210 info
       character*10 optdepth
       character*12 freqstring
       character*20 mesg
+      character*24 transname
       character*2 comml(2)
 
       common /options/ precomm,prestruc,overwr,fileinp,numdef,
@@ -999,18 +1002,20 @@ c     Translate from arcsec to degree
       data comml / '##','!!'/
       data stdext / 'fits','scan','line' /
 
-13    format(/,' Name of the output file for the line profiles: ',$)
+11    format(/,' Writing line intensity profiles to output file')
+12    format(/,' Writing optical depth profiles to output file')
+13    format(/,' Name of the output file: ',$)
 14    format(' File structure [FITS = 0/lines = 1/compact = 2]: ',$)
 15    format(' Comment line format [none = 0/UNIX = 1/VMS = 2]: ',$) 
 c     Input formats
-42    format(A80)
+42    format(A250)
 c     Output lines
 81    format(A2,' Offset of first entry: ',E10.3)
 82    format(A2,' Frequency of first entry: ',E10.3)
 91    format(A2,' Offset step size: ',E10.3)
 92    format(A2,' Frequency step size: ',E10.3)
-85    format(A2,' Line map produced by SimLine '
-     %    //'(V.Ossenkopf-Okada 1999-2017)')
+85    format(A2,' Position-velocity map produced by SimLine '
+     %    //'(V.Ossenkopf-Okada 1999-2026)')
 83    format(A2,' Transition: ',A20)
 84    format(A2,' Frequency: ',A20)
 86    format(A2,' Number of offset points: ',I4)
@@ -1020,6 +1025,15 @@ c     Output lines
 45    format(1P,E9.2,E11.3,E12.4)
 46    format(1P,223E11.4)
 
+c     Opening
+      if (istau) then
+        write(6,12)
+        call clearstring(mesg,usedlen,.true.)
+        transname=mesg(1:usedlen)//'-tau'
+      else
+        write(6,11)
+        transname=mesg
+      endif
       leer=' '
 c     *************************************************************
 c     The format of the output files may be selected on compile 
@@ -1037,13 +1051,13 @@ c     *************************************************************
 c     Construct or get file name
 c     *************************************************************
       if (.not.anames) lfile=leer
-      call clearstring(mesg,mend,.true.)
+      call clearstring(transname,mend,.true.)
 350   if (lfile.eq.leer) then
-       write(6,13)
-       read (5,42) lfile
+        write(6,13)
+        read (5,42) lfile
       else
        call clearstring(lfile,lend,.false.)
-       newname=lfile(1:lend)//'.'//mesg(1:mend)//'.'//useext
+       newname=lfile(1:lend)//'.'//transname(1:mend)//'.'//useext
        lfile=newname
       endif
 c     *************************************************************
@@ -1053,19 +1067,24 @@ c     *************************************************************
       write(optdepth,'(E10.3)') tau
       write(freqstring,'(E12.5)') nu0
 c     Make strings that always fill the 80 character lines in FITS
-      info= 'Line map produced by SimLine'//
-     %     ' (V.Ossenkopf-Okada 1997-2025)             '//
+      info= 'Position-velocity map produced by SimLine'//
+     %     ' (V.Ossenkopf-Okada 1997-2026)'//
      %     ' Transition: '//mesg//
      %     '         Rest frequency: '//freqstring//
      %     '   Central optical depth: '//optdepth//
      %     '                '
       nax(1)=nbeam
       nax(2)=2*nff+1
-      units(0)='K'
-      comm(0)='Beam temperature'
+      if (istau) then
+        units(0)=''
+        comm(0)='Optical depth'
+      else
+        units(0)='K'
+        comm(0)='Beam temperature'
+      endif
       units(1)='RA---TAN'
       comm(1)='in degrees'
-      units(2)='FREQ'
+      units(2)='VELOCITY'
       comm(2)=' in km/s'
 
       v0(0)=0.0
@@ -1084,7 +1103,7 @@ c     Resort frequencies, put to linear field for writing
       kerr=0
       call savefits(2,nax,daten,v0,dv,units,comm,info,nu0,lfile,kerr)
 c     Correct file name
-      lend=index(lfile,'.'//mesg(1:mend)//'.'//useext)
+      lend=index(lfile,'.'//transname(1:mend)//'.'//useext)
       if (lend.gt.0) then
        newname=lfile(1:lend)//useext
        lfile=newname
@@ -1141,7 +1160,7 @@ c     3-column structure
       endif
       close(14)
 c     Correct file name
-      lend=index(lfile,'.'//mesg(1:mend)//'.'//useext)
+      lend=index(lfile,'.'//transname(1:mend)//'.'//useext)
       if (lend.gt.0) then
        newname=lfile(1:lend)//useext
        lfile=newname
@@ -1169,7 +1188,7 @@ c     ***********************************************************
       character*8 units(0:3)
       character*40 comments(0:3)
       real daten(*)
-      character*80 lfile,leer
+      character*250 lfile,leer
       character*210 info
 
       integer i,ioerror
@@ -1185,7 +1204,7 @@ c     ***********************************************************
 
 c     Input formats
 13      format(/,' Name of the output FITS file: ',$)
-42    format(A80)
+42    format(A250)
 
 c     *************************************************************
 c     Open the file for writing
@@ -1209,7 +1228,8 @@ c     *************************************************************
       extend=.true.
       naxis=ndim
       do 210 i=1,ndim
-210    naxes(i)=nx(i)
+        naxes(i)=nx(i)
+210   continue
       call ftphpr(14,simple,bitpix,naxis,naxes,0,1,extend,status)
 c     *************************************************************
 c     Extended header
@@ -1233,7 +1253,8 @@ c     ************************************************************
       fpixel=1
       nelements=1
       do 110 i=1,ndim
-110    nelements=nelements*nx(i)
+        nelements=nelements*nx(i)
+110   continue
       call ftppre(14,group,fpixel,nelements,daten,status)
       call ftclos(14,status)
       if (status.gt.0) then
@@ -1312,7 +1333,7 @@ c     Subroutine for general file I/O error handling
 c     *************************************************************
       integer function ioerror(lfile,inum)
       implicit none
-      character*80 lfile
+      character*250 lfile
       character yn
       integer inum
 
@@ -1323,11 +1344,11 @@ c     *************************************************************
       save /options/
 
 41    format(A1)
-51    format(/,' I cannot open the input file ',A80)
-52    format(//,' Format error in input file ',A80)
-53    format(/,' This file exists already: ',A80)
+51    format(/,' I cannot open the input file ',A250)
+52    format(//,' Format error in input file ',A250)
+53    format(/,' This file exists already: ',A250)
 54    format(' Shall I replace it ? [y/n]: ',$)
-56    format(' I cannot open the output file ',A80)
+56    format(' I cannot open the output file ',A250)
 57    format(' Use another file ? [y/n]: ',$)
 55    format(' Continue ? [y/n]: ',$)
 59    format(//,' Stop on all errors requested. Program halted.')
@@ -1394,14 +1415,15 @@ c     line argument. ! This part is not standard-FORTRAN77 and
 c     may not compile everywhere ! Taking defaults, you will be 
 c     asked for the options at all file output operations.
 c     ***********************************************************
-      subroutine predefine(allexit,part1only)
+      subroutine predefine(allexit,part1only,tauwrite)
       integer nmax,narg,iargc,i
       integer precomm,prestruc
-      logical overwr,numdef,fileinp,anames,allstop,allexit,part1only
+      logical overwr,numdef,fileinp,anames,allstop,allexit,
+     %  part1only,tauwrite
       character*20 string
       character*20 stover(2),stblock(2),stlines(2),stnocom(2),
      %  stunixcom(2),stvmscom(2),stnumdef(2),stfile(2),stfits(2),
-     %  stanames(2),ststop(2),stpopulate(2)
+     %  stanames(2),ststop(2),stpopulate(2),sttauwrite(2)
 
       common /options/ precomm,prestruc,overwr,fileinp,numdef,
      %                   anames,allstop
@@ -1420,6 +1442,7 @@ c     All allowed possibilities of command line parameters
       data stanames /'-autonames','-AUTONAMES'/
       data ststop /'-stoponerror','-STOPONERROR'/
       data stpopulate /'-populateonly','-POPULATEONLY'/
+      data sttauwrite /'-writetau','-WRITETAU'/
 
 c     ***********************************************************
 c     Default values (interactive mode)
@@ -1432,6 +1455,7 @@ c     ***********************************************************
       anames=.false.
       allstop=.false.
       part1only=.false.
+      tauwrite=.false.
 c     ***********************************************************
 c     Compile time defaults
 c     (may be activated on systems with preprocessor cpp)
@@ -1453,6 +1477,9 @@ c     precomm=1
 c     #elif defined (vmscomments)
 c     precomm=2
 c     #endif
+c     #if defined (writetau)
+c     tauwrite=.true.
+c     #endif
 c     ************************************************************
 c     Overwrite compile time defaults by command line parameters
 c     ************************************************************
@@ -1472,6 +1499,7 @@ c     ************************************************************
       if (string.eq.stanames(i)) anames=.true.
       if (string.eq.ststop(i)) allstop=.true.
       if (string.eq.stpopulate(i)) part1only=.true.
+      if (string.eq.sttauwrite(i)) tauwrite=.true.
 100   continue
         allexit=allstop
       return
