@@ -4,7 +4,7 @@ c     for one transition
 c     This is a reduced version of stpmic for only one line
 c     ***********************************************************
       subroutine stpline(r,v,dlb,caps,ss,nn,uext,p,indr,iout,
-     %                     nnp,nff,dny)
+     %                     tautot,nnp,nff,dny)
       implicit none
       integer nn,nnp,nff
 
@@ -12,10 +12,10 @@ c     ***********************************************************
       real r(ns),v(ns),dlb(ns)
       real caps(ns),ss(ns)
       real uext,dny
-      real iout(nstretch,-nf:nf),p(nstretch)
+      real iout(nstretch,-nf:nf),tautot(nstretch,-nf:nf),p(nstretch)
       integer indr(nstretch)
 
-      real cap(-nf:nf),iplus(-nf:nf)
+      real cap(-nf:nf),iplus(-nf:nf),tauaccu(-nf:nf)
       real cpo,sco,cp,sca
 
       real y,vs,vv,dv,yo,vso,vo,dvo,rr,dr,dy2,p2,fak
@@ -30,7 +30,9 @@ c     If the last ray is touching - separated treatment
 c     ********************************************************
       if (indr(nnp).eq.2*nn) then
       do 200 j=-nff,nff
-200   iout(nnp,j) = uext
+      tautot(nnp,j) = 0.0
+       iout(nnp,j) = uext
+200   continue
       nnk=nnp-1
       else
       nnk=nnp
@@ -65,8 +67,10 @@ c     Geometry parameters
       vso = vo*yo /rr
       dvo = dlb(kk)
 c     Background for all frequencies
-      do 500 j=-nff,nff
-500   iplus(j) = uext
+      do 500 j=-nff,nf
+      tauaccu(j)= 0.0
+      iplus(j) = uext
+500   continue
 c     Initialize kappa and source function fields
       cpo=caps(kk)
       sco=ss(kk)
@@ -94,11 +98,11 @@ c     gradient is too large
 c     *******************************************************
       call firstlstp(yo,vo,vso,dvo,cpo,sco,
      %                 y,vv,vs,dr,dv,cp,sca,p(i),dy2,itstp)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
       if (itstp.gt.0) then
       do 640 it=1,itstp
       call nextlstp(vso,dvo,cpo,sca,dy2)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
 640   continue
       endif
 1600  continue
@@ -116,7 +120,7 @@ c     ********************************************************
       dy2 = -2.0*yo
       cp=caps(kk)
       sca=ss(kk)
-      call ctransfl(cp,sca,iplus,nff,dy2)
+      call ctransfl(cp,sca,iplus,tauaccu,nff,dy2)
 c     ********************************************************
 c     Treatment of the point at the other side of the HII region
 c     by a 0 length transfer in the next transfer step
@@ -160,7 +164,7 @@ c     *******************************************************
       vs=vso
       call firstlstp(yo,vo,vso,dvo,cpo,sco,
      %                 y,vv,vs,dr,dv,cp,sca,p(i),dy2,itstp)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
 c     New kappa field in case of a velocity jump
       if (vso.ne.0.0) then
       vso=-vso
@@ -172,11 +176,11 @@ c     Multiple steps if the velocity gradient is too large
 c     *******************************************************
       call firstlstp(yo,vo,vso,dvo,cpo,sco,
      %                 y,vv,vs,dr,dv,cp,sca,p(i),dy2,itstp)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
       if (itstp.gt.0) then
       do 840 it=1,itstp
       call nextlstp(vso,dvo,cpo,sca,dy2)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
 840   continue
       endif
       endif
@@ -201,11 +205,11 @@ c     gradient is too large
 c     *******************************************************
       call firstlstp(yo,vo,vso,dvo,cpo,sco,
      %                 y,vv,vs,dr,dv,cp,sca,p(i),dy2,itstp)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
       if (itstp.gt.0) then
       do 740 it=1,itstp
       call nextlstp(vso,dvo,cpo,sca,dy2)
-      call transfl(cpo,sca,iplus,cap,sco,j1,j2,vso,dvo,dny,dy2)
+      call transfl(cpo,sca,iplus,tauaccu,cap,sco,j1,j2,vso,dvo,dny,dy2)
 740   continue
       endif
 1700  continue
@@ -215,6 +219,7 @@ c     End of the z loop
 c     Store the results into a large field
 c     **********************************************************
       do 420 j=-nff,nff
+      tautot(i,j) = tauaccu(j)
       iout(i,j) = iplus(j)
 420   continue
 400   continue
@@ -513,15 +518,16 @@ c     Frequency dependent quantities
 c     ***********************************************************
 c     Subroutine for radiative transfer between two points
 c     This is a reduced version of transfer for only one line
+c     But additional accumulator for tau added
 c     ***********************************************************
-      subroutine transfl(cp,sc,iplus,cap,ss,j1,j2,vs,dv,dny,z)
+      subroutine transfl(cp,sc,iplus,tauaccu,cap,ss,j1,j2,vs,dv,dny,z)
       implicit none
       integer j1,j2
 
       include 'fsizes.inc'
       real cp,sc,ss
       real cap(-nf:nf)
-      real iplus(-nf:nf)
+      real iplus(-nf:nf),tauaccu(-nf:nf)
       real vs,dv,dny,z
       real negexp,negint,explin,softzone
       real phi,prof,tau1,tau2,tau,tauq
@@ -549,11 +555,13 @@ c     *******************************************************
       prof = phi(j*dny,vs,dv)
       cap(j) = cp*prof 
       tau = z*cap(j)
+      tauaccu(j)=tauaccu(j)+tau
       iplus(j)=(iplus(j)+sc*tau)/(1.0+tau)
 510   continue
       else if (j1.lt.jj1) then
       do 520 j=j1,jj1-1
       tau = z*cap(j)
+      tauaccu(j)=tauaccu(j)+tau
       iplus(j)=(iplus(j)+ss*tau)/(1.0+tau)
 520   continue
       endif
@@ -574,8 +582,10 @@ c     ******************************************************
       cap(j) = cp*prof 
       tau2 = z*cap(j)
       tauq = tau1*tau2
+      tau = tau1+tau2
+      tauaccu(j) = tauaccu(j)+tau
       iplus(j) = (iplus(j)+sc*tau2+ss*tau1
-     %   +0.66667*tauq*(2.0*sc+ss))/(1.0+tau1+tau2+2.0*tauq)
+     %   +0.66667*tauq*(2.0*sc+ss))/(1.0+tau+2.0*tauq)
 500   continue
       else
 c     ******************************************************
@@ -592,6 +602,7 @@ c     ******************************************************
       tau2 = z*cap(j)
       tau=tau1+tau2
       rel = abs(tau)
+      tauaccu(j) = tauaccu(j)+tau
       if (rel.lt.explin) then
 c     Thin case - linear approx.
       tauq = tau1*tau2
@@ -601,7 +612,7 @@ c     Thin case - linear approx.
 c     Small transition regime - superposition
       tauq = tau1*tau2
       ihlp1 = (iplus(j)+sc*tau2+ss*tau1
-     %	 +0.66667*tauq*(2.0*sc+ss))/(1.0+tau+2.0*tauq)
+     %  +0.66667*tauq*(2.0*sc+ss))/(1.0+tau+2.0*tauq)
       ex1=exp(-0.33333*tau1)
       ex2=exp(-0.33333*tau2)
       g1=0.5*(ss-sc)
@@ -625,11 +636,13 @@ c     *******************************************************
       prof = phi(j*dny,vs,dv)
       cap(j) = cp*prof
       tau = z*cap(j) 
+      tauaccu(j)=tauaccu(j)+tau
       iplus(j)=(iplus(j)+sc*tau)/(1.0+tau)
 560   continue
       else if (j2.gt.jj2) then
       do 570 j=jj2+1,j2
       tau = z*cap(j)
+      tauaccu(j)=tauaccu(j)+tau
       iplus(j)=(iplus(j)+ss*tau)/(1.0+tau)
 570   continue
       endif
@@ -645,14 +658,15 @@ c     *******************************************************
 c     ***********************************************************
 c     Subroutine for the radiative transfer in the continuum
 c     This is a reduced version of ctransfer for only one line
+c     But additional accumulator for tau added
 c     ***********************************************************
-      subroutine ctransfl(cp,sc,iplus,nff,z)
+      subroutine ctransfl(cp,sc,iplus,tauaccu,nff,z)
       implicit none
       integer nff
 
       include 'fsizes.inc'
       real cp,sc
-      real iplus(-nf:nf)
+      real iplus(-nf:nf),tauaccu(-nf:nf)
       real z,tau,tauq,xx
       real explin,softzone
       integer j
@@ -668,16 +682,18 @@ c     ******************************************************
 c     ******************************************************
 c     Linear approximation for optically thin ranges
 c     ******************************************************
-      do 650 j=-nff,nff
       tauq = 0.5*tau**2
+      do 650 j=-nff,nff
+      tauaccu(j) = tauaccu(j)+tau
       iplus(j) = (iplus(j)+sc*(tau+tauq))/(1.0+tau+tauq)
 650   continue
       else
 c     ******************************************************
 c     Exponential function for thick ranges
 c     ******************************************************
-      do 680 j=-nff,nff
       xx=exp(-tau)
+      do 680 j=-nff,nff
+      tauaccu(j) = tauaccu(j)+tau
       iplus(j)=xx*(iplus(j)-sc) + sc
 680   continue
       endif
